@@ -17,12 +17,14 @@
 #include <QMimeData>
 #include <QMimeDatabase>
 #include <QPainter>
+#include <QPrinter>
 #include <QRandomGenerator>
 #include <QRegularExpression>
 #include <QRegularExpressionMatch>
 #include <QString>
 #include <QTemporaryDir>
 #include <QTemporaryFile>
+#include <QWindow>
 
 #include <KIO/FileCopyJob>
 #include <KIO/ListJob>
@@ -30,8 +32,8 @@
 #include <KIO/StatJob>
 #include <KRecentDocument>
 #include <KSharedConfig>
+#include <KSystemClipboard>
 #include <KWindowSystem>
-#include <QWindow>
 
 ExportManager::ExportManager(QObject *parent)
     : QObject(parent)
@@ -51,6 +53,8 @@ ExportManager::~ExportManager()
 ExportManager *ExportManager::instance()
 {
     static ExportManager instance;
+    // Ensure the SystemClipboard is instantiated early enough
+    KSystemClipboard::instance();
     return &instance;
 }
 
@@ -180,6 +184,7 @@ QString ExportManager::formatFilename(const QString &nameTemplate)
                          .replace(QLatin1String("%H"), timestamp.toString(QStringLiteral("hh")))
                          .replace(QLatin1String("%m"), timestamp.toString(QStringLiteral("mm")))
                          .replace(QLatin1String("%S"), timestamp.toString(QStringLiteral("ss")))
+                         .replace(QLatin1String("%t"), timestamp.toString(QStringLiteral("t")))
                          .replace(QLatin1String("%T"), title);
 
     // check if basename includes %[N]d token for sequential file numbering
@@ -280,7 +285,7 @@ QString ExportManager::autoIncrementFilename(const QString &baseName, const QStr
 QString ExportManager::makeSaveMimetype(const QUrl &url)
 {
     QMimeDatabase mimedb;
-    QString type = mimedb.mimeTypeForUrl(url).preferredSuffix();
+    const QString type = mimedb.mimeTypeForUrl(url).preferredSuffix();
 
     if (type.isEmpty()) {
         return Settings::self()->defaultSaveImageFormat().toLower();
@@ -419,7 +424,7 @@ bool ExportManager::save(const QUrl &url)
         return false;
     }
 
-    QString mimetype = makeSaveMimetype(url);
+    const QString mimetype = makeSaveMimetype(url);
     bool saveSucceded = false;
     if (url.isLocalFile()) {
         saveSucceded = localSave(url, mimetype);
@@ -536,29 +541,13 @@ void ExportManager::doSaveAndCopy(const QUrl &url)
 // misc helpers
 void ExportManager::doCopyToClipboard(bool notify)
 {
-    const auto copyToClipboard = [this, notify]() {
-        auto data = new QMimeData();
-        data->setImageData(mSavePixmap.toImage());
-        data->setData(QStringLiteral("x-kde-force-image-copy"), QByteArray());
-        QApplication::clipboard()->setMimeData(data, QClipboard::Clipboard);
-        Q_EMIT imageCopied();
-        if (notify) {
-            Q_EMIT forceNotify(QUrl());
-        }
-    };
-
-    if (KWindowSystem::isPlatformWayland() && !QGuiApplication::focusWindow()) {
-        // under wayland you can copy to clipboard only from a focused window
-        // delay the copy until after a window has focus
-        QMetaObject::Connection *connection = new QMetaObject::Connection;
-        *connection = connect(qApp, &QGuiApplication::focusWindowChanged, this, [copyToClipboard, connection](const QWindow *) {
-            disconnect(*connection);
-            delete connection;
-
-            copyToClipboard();
-        });
-    } else {
-        copyToClipboard();
+    auto data = new QMimeData();
+    data->setImageData(mSavePixmap.toImage());
+    data->setData(QStringLiteral("x-kde-force-image-copy"), QByteArray());
+    KSystemClipboard::instance()->setMimeData(data, QClipboard::Clipboard);
+    Q_EMIT imageCopied();
+    if (notify) {
+        Q_EMIT forceNotify(QUrl());
     }
 }
 
@@ -610,6 +599,7 @@ const QMap<QString, KLocalizedString> ExportManager::filenamePlaceholders{
     {QStringLiteral("%H"), ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Hour")},
     {QStringLiteral("%m"), ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Minute")},
     {QStringLiteral("%S"), ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Second")},
+    {QStringLiteral("%t"), ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Timezone")},
     {QStringLiteral("%T"), ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Window Title")},
     {QStringLiteral("%d"), ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Sequential numbering")},
     {QStringLiteral("%Nd"),
