@@ -7,41 +7,39 @@
 
 #include <SpectacleCommon.h>
 
-#include <QObject>
-#include <QIODevice>
-#include <QMap>
-#include <QPrinter>
-#include <QPixmap>
-#include <QDateTime>
-#include <QUrl>
 #include <KLocalizedString>
+#include <QDateTime>
+class QIODevice;
+#include <QMap>
+#include <QObject>
+#include <QPixmap>
+class QPrinter;
+#include <QUrl>
 
 class QTemporaryDir;
 
-class ExportManager: public QObject
+class ExportManager : public QObject
 {
     Q_OBJECT
 
     // singleton-ize the class
 
-    public:
-
-    static ExportManager* instance();
-
-    private:
+public:
+    static ExportManager *instance();
 
+private:
     explicit ExportManager(QObject *parent = nullptr);
-    virtual ~ExportManager();
+    ~ExportManager() override;
 
-    ExportManager(ExportManager const&) = delete;
-    void operator= (ExportManager const&) = delete;
+    ExportManager(ExportManager const &) = delete;
+    void operator=(ExportManager const &) = delete;
 
     // now the usual stuff
 
-    public:
-
+public:
     QString defaultSaveLocation() const;
     bool isFileExists(const QUrl &url) const;
+    bool isImageSavedNotInTemp() const;
     void setPixmap(const QPixmap &pixmap);
     QPixmap pixmap() const;
     void updatePixmapTimestamp();
@@ -53,7 +51,7 @@ class ExportManager: public QObject
 
     static const QMap<QString, KLocalizedString> filenamePlaceholders;
 
-    Q_SIGNALS:
+Q_SIGNALS:
 
     void errorMessage(const QString &str);
     void imageSaved(const QUrl &savedAt);
@@ -62,7 +60,7 @@ class ExportManager: public QObject
     void imageSavedAndCopied(const QUrl &savedAt);
     void forceNotify(const QUrl &savedAt);
 
-    public Q_SLOTS:
+public Q_SLOTS:
 
     QUrl getAutosaveFilename();
     QUrl tempSave();
@@ -75,13 +73,11 @@ class ExportManager: public QObject
     void doCopyLocationToClipboard(bool notify = false);
     void doPrint(QPrinter *printer);
 
-    private:
-
+private:
     QString truncatedFilename(const QString &filename);
     QString makeAutosaveFilename();
-    using FileNameAlreadyUsedCheck = bool (ExportManager::*)(const QUrl&) const;
-    QString autoIncrementFilename(const QString &baseName, const QString &extension,
-                                  FileNameAlreadyUsedCheck isFileNameUsed);
+    using FileNameAlreadyUsedCheck = bool (ExportManager::*)(const QUrl &) const;
+    QString autoIncrementFilename(const QString &baseName, const QString &extension, FileNameAlreadyUsedCheck isFileNameUsed);
     QString makeSaveMimetype(const QUrl &url);
     bool writeImage(QIODevice *device, const QByteArray &format);
     bool save(const QUrl &url);
@@ -89,11 +85,12 @@ class ExportManager: public QObject
     bool remoteSave(const QUrl &url, const QString &mimetype);
     bool isTempFileAlreadyUsed(const QUrl &url) const;
 
+    bool mImageSavedNotInTemp;
     QPixmap mSavePixmap;
     QDateTime mPixmapTimestamp;
     QUrl mTempFile;
-    QTemporaryDir *mTempDir;
+    QTemporaryDir *mTempDir = nullptr;
     QList<QUrl> mUsedTempFileNames;
     QString mWindowTitle;
-    Spectacle::CaptureMode mCaptureMode { Spectacle::CaptureMode::AllScreens };
+    Spectacle::CaptureMode mCaptureMode{Spectacle::CaptureMode::AllScreens};
 };
